# ruff: noqa
# black: skip
# mypy: ignore-errors

from .multilang_prompt import MultiLangContainer, MultiLangPromptTemplateCollection, PromptList


class PromptFactory:
    # NOTE: This class is auto-generated by gen_prompt_factory.py

    def __init__(self, lang_shortcode: str = "en", fallback_mode=MultiLangContainer.FallbackMode.EXCEPTION):
        self.lang_shortcode = lang_shortcode
        self.collection = MultiLangPromptTemplateCollection()
        self.fallback_mode = fallback_mode

    def _format_prompt(self, prompt_name: str, kwargs) -> str:
        del kwargs["self"]
        mpt = self.collection.get_multilang_prompt_template(prompt_name)
        return mpt.get_item(self.lang_shortcode, self.fallback_mode).instantiate(**kwargs)

    def _get_list(self, prompt_name: str) -> PromptList:
        mpl = self.collection.get_multilang_prompt_list(prompt_name)
        return mpl.get_item(self.lang_shortcode, self.fallback_mode)

    def create_onboarding_prompt(self, *, system) -> str:
        return self._format_prompt("onboarding_prompt", locals())

    def create_think_about_collected_information(self) -> str:
        return self._format_prompt("think_about_collected_information", locals())

    def create_think_about_task_adherence(self) -> str:
        return self._format_prompt("think_about_task_adherence", locals())

    def create_think_about_whether_you_are_done(self) -> str:
        return self._format_prompt("think_about_whether_you_are_done", locals())

    def create_summarize_changes(self) -> str:
        return self._format_prompt("summarize_changes", locals())

    def create_prepare_for_new_conversation(self) -> str:
        return self._format_prompt("prepare_for_new_conversation", locals())

    def create_system_prompt(self) -> str:
        return self._format_prompt("system_prompt", locals())
